Documentation
¶
Overview ¶
Package grpcerrassert provides assertions for gRPC status errors.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NonStatus ¶
func NonStatus() errassert.ErrorAssertion
NonStatus returns an assertion that checks if the error is not a gRPC status.
func SomeStatus ¶
func SomeStatus() errassert.ErrorAssertion
SomeStatus returns an assertion that checks if the error is a gRPC status.
func StatusCode ¶
func StatusCode(expectedCode codes.Code) errassert.ErrorAssertion
StatusCode returns an assertion that checks if the status code matches the expected one.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.